# Conditionals to help breaking azure-sdk-java(azure-mgmt-dns) <-> azure-storage dependency cycle
%if 0%{?fedora}
%bcond_with azure_storage
# Unavailable deps
%bcond_with jjwt
# wiremock required NON free jsonassert
# https://github.com/skyscreamer/JSONassert/issues/49
%bcond_with wiremock
%endif

Name:          azure-sdk-java
Version:       0.9.4
Release:       1%{?dist}
Summary:       Microsoft Azure Management Libraries for Java
License:       ASL 2.0
URL:           https://azure.microsoft.com/en-us/develop/java/
Source0:       https://github.com/Azure/azure-sdk-for-java/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires: maven-local
BuildRequires: mvn(com.fasterxml.jackson.core:jackson-core)
BuildRequires: mvn(com.google.guava:guava)
BuildRequires: mvn(com.microsoft.azure:adal4j)
BuildRequires: mvn(com.sun.jersey:jersey-client:1)
BuildRequires: mvn(com.sun.jersey:jersey-json:1)
BuildRequires: mvn(commons-codec:commons-codec)
BuildRequires: mvn(commons-io:commons-io)
BuildRequires: mvn(commons-lang:commons-lang)
BuildRequires: mvn(commons-logging:commons-logging)
%if %{without jjwt}
BuildRequires: mvn(com.fasterxml.jackson.core:jackson-annotations)
BuildRequires: mvn(com.fasterxml.jackson.core:jackson-databind)
BuildRequires: mvn(io.jsonwebtoken:jjwt)
%endif
BuildRequires: mvn(javax.inject:javax.inject)
BuildRequires: mvn(javax.mail:mail)
BuildRequires: mvn(javax.xml.bind:jaxb-api)
BuildRequires: mvn(org.apache.commons:commons-lang3)
BuildRequires: mvn(org.apache.httpcomponents:httpclient)
BuildRequires: mvn(org.bouncycastle:bcprov-jdk16)
BuildRequires: mvn(org.jvnet.jaxb2_commons:jaxb2-basics)
BuildRequires: mvn(org.jvnet.jaxb2_commons:jaxb2-basics-annotate)
BuildRequires: mvn(org.jvnet.jaxb2.maven2:maven-jaxb22-plugin)
BuildRequires: mvn(org.slf4j:slf4j-jdk14)

%if %{with wiremock}
BuildRequires: mvn(com.github.tomakehurst:wiremock)
# test deps
%if %{with azure_storage}
BuildRequires: mvn(com.microsoft.azure:azure-storage:1.2.0)
%endif
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(junit:junit-dep)
BuildRequires: mvn(org.hamcrest:hamcrest-all)
BuildRequires: mvn(org.mockito:mockito-all)
%endif

BuildArch:     noarch

%description
This is the core module of Microsoft Azure SDK.

%package bom
Summary:       Microsoft Azure SDK Bill of Materials

%description bom
Centralized dependency Management for the
Microsoft Azure SDK Project.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%package keyvault
Summary:       Microsoft Azure SDK for Key Vault

%description keyvault
This package contains Microsoft Azure SDK for Key Vault.

%package media
Summary:       Microsoft Azure SDK for Media Services

%description media
This package contains Microsoft Azure SDK for Media Services.

%package mgmt-samples
Summary:       Microsoft Azure SDK Core Samples

%description mgmt-samples
This module contains ARM examples of functionality in Microsoft Azure SDK.

%package parent
Summary:       Microsoft Azure SDK Parent POM

%description parent
This package contains the parent POM of Microsoft Azure SDK.

%package resource-management
Summary:       Microsoft Azure SDK for Resources Management

%description resource-management
This package contains Microsoft Azure SDK for Resources Management.

%package service-management
Summary:       Microsoft Azure SDK for Service Management

%description service-management
This package contains Microsoft Azure SDK for Service Management.

%package servicebus
Summary:       Microsoft Azure SDK for Service Bus

%description servicebus
This package contains Microsoft Azure SDK for Service Bus.

%package serviceruntime
Summary:       Microsoft Azure SDK for Service Runtime

%description serviceruntime
This package contains Microsoft Azure SDK for service runtime.

%package tracing-util
Summary:       Microsoft Azure SDK tracing logger utility

%description tracing-util
This package contains tracing with util logger in the Microsoft Azure SDK.

%prep
%setup -q -n azure-sdk-for-java-%{version}

%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :maven-help-plugin
%pom_remove_plugin -r :findbugs-maven-plugin

%if %{without wiremock}
%pom_disable_module  ../core/azure-core-test azure
 %if %{without azure_storage}
# TODO
 %endif
%endif

%if %{with jjwt}
%pom_disable_module  ../services/azure-media azure
%endif


%pom_change_dep -r com.sun.jersey: ::1

# org.jvnet.jaxb2.maven2:maven-jaxb2-plugin:0.9.1
%pom_xpath_set "pom:plugin[pom:groupId = 'org.jvnet.jaxb2.maven2' ]/pom:artifactId" maven-jaxb22-plugin services/azure-servicebus

# fix non ASCII chars
for s in resource-management/azure-mgmt-compute/src/main/java/com/microsoft/azure/management/compute/models/VirtualMachineExtensionImageListVersionsParameters.java \
  resource-management/azure-mgmt-compute/src/main/java/com/microsoft/azure/management/compute/models/VirtualMachineImageListSkusParameters.java \
  resource-management/azure-mgmt-compute/src/main/java/com/microsoft/azure/management/compute/models/VirtualMachineImageListParameters.java \
  resource-management/azure-mgmt-storage/src/main/java/com/microsoft/azure/management/storage/models/ProvisioningState.java \
  resource-management/azure-mgmt-network/src/main/java/com/microsoft/azure/management/network/models/SecurityRule.java \
  resource-management/azure-mgmt-traffic-manager/src/main/java/com/microsoft/azure/management/trafficmanager/models/EndpointProperties.java \
  service-management/azure-svc-mgmt-network/src/main/java/com/microsoft/windowsazure/management/network/models/NetworkSecurityRule.java \
  service-management/azure-svc-mgmt-network/src/main/java/com/microsoft/windowsazure/management/network/models/NetworkSecuritySetRuleParameters.java \
  service-management/azure-svc-mgmt-compute/src/main/java/com/microsoft/windowsazure/management/compute/models/OSVirtualHardDisk.java \
  service-management/azure-svc-mgmt-compute/src/main/java/com/microsoft/windowsazure/management/compute/models/ResourceExtensionReference.java \
  services/azure-media/src/main/java/com/microsoft/windowsazure/services/media/models/AssetInfo.java \
  services/azure-media/src/main/java/com/microsoft/windowsazure/services/media/implementation/content/AssetType.java
 do
  native2ascii -encoding UTF8 ${s} ${s}
done

%mvn_package ":azure-keyvault*" keyvault
%mvn_package ":azure-mgmt-compute" resource-management
%mvn_package ":azure-mgmt-dns" resource-management
%mvn_package ":azure-mgmt-network" resource-management
%mvn_package ":azure-mgmt-notificationhubs" resource-management
%mvn_package ":azure-mgmt-resources" resource-management
%mvn_package ":azure-mgmt-sql" resource-management
%mvn_package ":azure-mgmt-storage" resource-management
%mvn_package ":azure-mgmt-traffic-manager" resource-management
%mvn_package ":azure-mgmt-utility" resource-management
%mvn_package ":azure-mgmt-websites" resource-management
%mvn_package ":azure-svc-*" service-management

%build

# Unavailable test deps: com.github.tomakehurst:wiremock:1.47
%if %{without azure_storage}
opts="-f"
%endif
%mvn_build -s $opts

%install
%mvn_install

%files -f .mfiles-azure-core
%doc ChangeLog.txt README.md
%license LICENSE.txt

%files bom -f .mfiles-azure-bom
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%files keyvault -f .mfiles-keyvault

%if %{without jjwt}
%files media -f .mfiles-azure-media
%endif

%files mgmt-samples  -f .mfiles-azure-mgmt-samples
%files parent -f .mfiles-azure
%license LICENSE.txt

%files resource-management -f .mfiles-resource-management
%files service-management -f .mfiles-service-management
%files servicebus -f .mfiles-azure-servicebus
%files serviceruntime -f .mfiles-azure-serviceruntime
%files tracing-util -f .mfiles-azure-tracing-util

%changelog
* Mon Sep 05 2016 gil cattaneo <puntogil@libero.it> 0.9.4-1
- initial rpm

